@@ -10,6 +10,7 @@
 #' The algorithm assumes a narrowing-down search will produce a decent fit.
 #'
 #' @keywords internal
+#' @noRd
 #' @param spread numeric
 #' @param min.dist numeric
 #' @param alim numeric vector of length 2, initial search range for parameter a
@@ -70,16 +71,18 @@ find.ab.params = function(spread, min.dist,
 
 
 
-#' Compute a value to capture how often each item contributes to layout optimization
+#' Compute a value to capture how often each item contributes to layout
+#' optimization
 #'
 #' @keywords internal
+#' @noRd
 #' @param w numeric vector or matrix
 #' @param epochs integer
 #'
 #' @return numeric vector of same length as w
 make.epochs.per.sample = function(w, epochs) {
   result = w
-  result[1:length(w)] = rep(-1, length(w))
+  result[seq_len(length(w))] = rep(-1, length(w))
   n.samples = epochs*(w/max(w))
   n.positive = n.samples>0
   result[n.positive] = epochs / n.samples[n.positive]
@@ -95,6 +98,7 @@ make.epochs.per.sample = function(w, epochs) {
 #' facilitate testing the Rcpp version.
 #'
 #' @keywords internal
+#' @noRd
 #' @param x numeric; single value or a vector
 #' @param xmax maximum value for x
 #'
@@ -110,6 +114,7 @@ clip = function(x, xmax=4) {
 #' Adjust a matrix so that each column is centered around zero
 #'
 #' @keywords internal
+#' @noRd
 #' @param x matrix
 #'
 #' @return matrix of same shape as x
@@ -124,8 +129,9 @@ center.embedding = function(x) {
 #' deterministically produce random-like integers for each column in a dataset
 #'
 #' @keywords internal
+#' @noRd
 #' @param x matrix, items in columns
-#' @param key numeric, a "salt" used trigger different random-like integers if needed
+#' @param key numeric, a "salt" used trigger different random-like integers
 #' @importFrom openssl md5
 #'
 #' @return vector of integers
@@ -139,7 +145,8 @@ column.seeds = function(x, key=123) {
   }
 
   # split up the large matrix into parts, then batch-md5 each part
-  # (splitting into parts avoids creating string-like representations of entire dataset)
+  # (splitting into parts avoids creating string-like representations
+  # of entire dataset)
   xlen = ncol(x)
   xparts = split(seq_len(xlen), floor(seq_len(xlen) / 256))
   result = rep(0, xlen)
