@@ -13,7 +13,7 @@ syn0[6,] = c(0.6, 0.2, 2.6)
 syn0[7,] = c(0.2, 3.5, 0.3)
 syn0[8,] = c(0.4, 3.1, 0.1)
 syn0[9,] = c(0.1, 3.3, 0.5)
-rownames(syn0) = letters[1:nrow(syn0)]
+rownames(syn0) = letters[seq_len(nrow(syn0))]
 syn0.dist = dist(syn0)
 
 ## classic cmdscale
